@@ -94,7 +94,7 @@
 ;	  (message "!!! This CCL interpreter have the valid MapMultiple instruction.
 ;!!! We enable all features on MUCS-CCL.")
 	  t)
-      (message "!!! Sorry. This CCL interpreter have faults on MapMultiple instruction.
+      (message "!!! Sorry.  This CCL interpreter have faults on MapMultiple instruction.
 !!! Some features on MUCS-CCL are disabled.")
       nil)))
 
@@ -125,7 +125,7 @@
 	      "\n"
 	      "If you would like to use this facility, please apply the patch for CCL to
 your Emacs, and MUST recompile ALL PACKAGES of Mule-UCS!
-For details, please refer README file of Mule-UCS"))))
+For detail, please refer README file of Mule-UCS"))))
 
 ;;;
 ;;; some simple ccl codes.
@@ -643,6 +643,7 @@ If UNIBYTE-P is non-nil, return a unibyte string as a result."
 		,(ccl-compile 
 		  (list 0
 			(mucs-ccl-myo-get-ccl myo)))))))
+      (mucs-notify-embedment 'mucs-ccl-required name)
       (setq ccl-pgm-list (cdr ccl-pgm-list)))
 ;   (message "MCCLREGFIN:%S" result)
     `(progn
