@@ -193,6 +193,9 @@ which is managed by TAE."
     tae-dependent-translations
     tae-dependent-conversions))
 
+(defsubst tae-get-translation-definition (name)
+  (symbol-value name))
+
 (defsubst tae-declared-translation-p (name)
   (and (symbolp name)
        (get name 'tae-translation)))
@@ -476,11 +479,13 @@ after its compilation."
 
 (defsubst tae-get-tr-elem-option-alist (tr-elem)
    (cond ((tae-tr-elem-assoc-p tr-elem)
- 	 (nth 3 tr-elem))
- 	((tae-tr-elem-range-p tr-elem)
- 	 (nth 3 tr-elem))
- 	((tae-tr-elem-ccl-p tr-elem)
- 	 (nth 3 tr-elem))))
+	  (nth 3 tr-elem))
+	 ((tae-tr-elem-range-p tr-elem)
+	  (nth 3 tr-elem))
+	 ((tae-tr-elem-ccl-p tr-elem)
+	  (nth 3 tr-elem))
+	 (t
+	  nil)))
 
 (defsubst tae-set-tr-elem-option-alist (tr-elem alist)
   (let (slot)
@@ -798,14 +803,12 @@ When DECODEP is t, reduce for decodeing translation."
 	(tr-curl (cdr tr-elems))
 	result-list result)
     (while tr2
-      (if (and (tae-get-tr-elem-all-key tr1)
-	       (tae-get-tr-elem-all-key tr2))
+      (if (tae-get-tr-elem-all-key tr2)
 	  (setq result tr1)
-	(if (not (tae-get-tr-elem-all-key tr2))
-	    (tae-set-tr-elem-all-key tr1 nil))
 	(setq result
 	      (cond ((and (tae-tr-elem-assoc-p tr1)
 			  (tae-tr-elem-assoc-p tr2))
+		     (tae-set-tr-elem-all-key tr1 nil)
 		     (let* (result-alist
 			    (alist1 (tae-get-tr-elem-assoc tr1))
 			    (alist2 (tae-get-tr-elem-assoc tr2))
@@ -1351,9 +1354,11 @@ according to it, rearrange the elements of UNIT."
 	(setq result-mes
 	      (tae-message-set-new-type result-mes to-type)))
       (if first-tbl
-	  (setq tbls (cons (list (cdr mes-tbl)
-				 (tae-project-all-table t))
-			   tbls))
+	  (setq tbls (cons 
+		      (cdr mes-tbl)
+		      (cons
+		       (tae-project-all-table t)
+		       tbls)))
 	(setq first-tbl (list (cdr mes-tbl))
 	      tbls first-tbl
 	      arith (tae-message-arithmetic-p mes)))
@@ -1362,7 +1367,7 @@ according to it, rearrange the elements of UNIT."
       (setq result-mes (tae-message-append result-mes mes)))
     (tae-message-set-arithmetic
      (tae-message-set-tables result-mes
-			     tbls)
+			     (list tbls))
      arith)))
 
 (defun tae-compile-composite-operation (translations type decodep)
