@@ -135,23 +135,33 @@ Definition must be a (nested) list of tables."
   "Inspect whether this table-set is nested or not.
 Nested table-set have at least one list that is consists of tables
 or lists of tables."
-  (let ((flag (get table-set 'table-set-nested))
-	cur symlist)
-    (if flag
-	(eq flag 'nested)
-      (setq symlist (get-table-set-symbol-list table-set))
-      (while (and (setq cur (car symlist))
-		  (not (consp cur))
-		  (symbolp cur)
-		  (not (and (table-set-p cur)
-			    (table-set-nested-p cur))))
-	(setq symlist (cdr symlist)))
-      (if symlist
-	  (progn
-	    (put table-set 'table-set-nested 'nested)
-	    t)
-	(put table-set 'table-set-nested 'not-nested)
-	nil))))
+;   (let ((flag (get table-set 'table-set-nested))
+; 	cur symlist)
+;     (if flag
+; 	(eq flag 'nested)
+;       (setq symlist (get-table-set-symbol-list table-set))
+;       (while (and (setq cur (car symlist))
+; 		  (not (consp cur))
+; 		  (symbolp cur)
+; 		  (not (and (table-set-p cur)
+; 			    (table-set-nested-p cur))))
+; 	(setq symlist (cdr symlist)))
+;       (if symlist
+; 	  (progn
+; 	    (put table-set 'table-set-nested 'nested)
+; 	    t)
+; 	(put table-set 'table-set-nested 'not-nested)
+; 	nil)))
+  (let (cur symlist)
+    (setq symlist (get-table-set-symbol-list table-set))
+    (while (and (setq cur (car symlist))
+		(not (consp cur))
+		(symbolp cur)
+		(not (and (table-set-p cur)
+			  (table-set-nested-p cur))))
+      (setq symlist (cdr symlist)))
+    symlist)
+)
 
 (defun clear-table-set (table-set)
   "Clear TABLE-SET.
