@@ -171,12 +171,13 @@ by calling post-read-conversion and pre-write-conversion functions.")
     (mapcar
      (lambda (cs)
        (cons cs
-	     `(list
-	       (mccl-font-convert-font-encoding)
-	       (tae-compile 
-		(quote
-		 ,(unicode-get-translation-rule-from-charset cs)))
-	       (mccl-font-flat-code-to-font-encoding 2))))
+	     (or (get cs 'mccl-font-encoder)
+		 `(list
+		   (mccl-font-convert-font-encoding)
+		   (tae-compile 
+		    (quote
+		     ,(unicode-get-translation-rule-from-charset cs)))
+		   (mccl-font-flat-code-to-font-encoding 2)))))
      unicode-basic-translation-charset-order-list))
 
 ;;
